@@ -9,9 +9,9 @@ use Moo::Role;
 use String::Escape qw/elide printable/;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-02-12'; # DATE
+our $DATE = '2023-11-06'; # DATE
 our $DIST = 'Org-To-HTML'; # DIST
-our $VERSION = '0.235'; # VERSION
+our $VERSION = '0.236'; # VERSION
 
 requires 'export_document';
 requires 'export_block';
@@ -49,7 +49,7 @@ Org::To::Role - Role for Org exporters
 
 =head1 VERSION
 
-This document describes version 0.235 of Org::To::Role (from Perl distribution Org-To-HTML), released on 2022-02-12.
+This document describes version 0.236 of Org::To::Role (from Perl distribution Org-To-HTML), released on 2023-11-06.
 
 =head1 HOMEPAGE
 
@@ -76,13 +76,14 @@ simply modify the code, then test via:
 
 If you want to build the distribution (e.g. to try to install it locally on your
 system), you can install L<Dist::Zilla>,
-L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
-Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
-beyond that are considered a bug and can be reported to me.
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2022, 2020, 2018, 2017, 2016, 2015, 2014, 2013, 2012, 2011 by perlancar <perlancar@cpan.org>.
+This software is copyright (c) 2023, 2022, 2020, 2018, 2017, 2016, 2015, 2014, 2013, 2012, 2011 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
